@@ -47,7 +47,7 @@ fi
 
 # JVM Configuration
 if [ -z "$JAVA_OPTS" ]; then
-  JAVA_OPTS=" -Doracle.jdbc.timezoneAsRegion=false"
+  JAVA_OPTS=" -Doracle.jdbc.timezoneAsRegion=false --add-opens=java.base/java.nio=org.apache.arrow.memory.core,ALL-UNNAMED"
 else
   JAVA_OPTS="${JAVA_OPTS} -Doracle.jdbc.timezoneAsRegion=false"
 fi
