@@ -17,8 +17,6 @@
  * under the License.
  */
 
-import { Tag } from './Tag';
-
 export class Monitor {
   id!: number;
   name!: string;
@@ -28,9 +26,10 @@ export class Monitor {
   // Monitoring status 0: Paused, 1: Up, 2: Down
   status!: number;
   description!: string;
+  labels!: Record<string, string>;
+  annotations!: Record<string, string>;
   creator!: string;
   modifier!: string;
   gmtCreate!: number;
   gmtUpdate!: number;
-  tags!: Tag[];
 }
