@@ -64,7 +64,6 @@ export class MonitorEditComponent implements OnInit {
   grafanaDashboard!: GrafanaDashboard;
   collectors!: Collector[];
   collector: string = '';
-  detected: boolean = false;
   isSpinning: boolean = false;
   spinningTip: string = 'Loading...';
 
@@ -93,14 +92,10 @@ export class MonitorEditComponent implements OnInit {
               });
               this.paramValueMap = paramValueMap;
             }
-            this.detected = false;
-            if (this.monitor.tags == undefined) {
-              this.monitor.tags = [];
-            }
           } else {
             console.warn(message.msg);
-            this.notifySvc.error(this.i18nSvc.fanyi('monitors.not-found'), message.msg);
-            return throwError(this.i18nSvc.fanyi('monitors.not-found'));
+            this.notifySvc.error(this.i18nSvc.fanyi('monitor.not-found'), message.msg);
+            return throwError(this.i18nSvc.fanyi('monitor.not-found'));
           }
           return this.appDefineSvc.getAppParamsDefine(this.monitor.app);
         })
@@ -149,6 +144,9 @@ export class MonitorEditComponent implements OnInit {
                 }
               }
               define.name = this.i18nSvc.fanyi(`monitor.app.${this.monitor.app}.param.${define.field}`);
+              if (define.placeholder == null && this.i18nSvc.fanyi(`monitor.${define.field}.tip`) != `monitor.${define.field}.tip`) {
+                define.placeholder = this.i18nSvc.fanyi(`monitor.${define.field}.tip`);
+              }
               if (define.hide) {
                 advancedParams.push(param);
                 advancedParamDefines.push(define);
@@ -192,63 +190,55 @@ export class MonitorEditComponent implements OnInit {
 
   onSubmit(info: any) {
     let addMonitor = {
-      detected: this.detected,
       monitor: info.monitor,
       collector: info.collector,
       params: info.params.concat(info.advancedParams),
       grafanaDashboard: info.grafanaDashboard
     };
-    if (this.detected) {
-      this.spinningTip = this.i18nSvc.fanyi('monitors.spinning-tip.detecting');
-    } else {
-      this.spinningTip = 'Loading...';
-    }
+    this.spinningTip = 'Loading...';
     this.isSpinning = true;
     this.monitorSvc.editMonitor(addMonitor).subscribe(
       message => {
         this.isSpinning = false;
         if (message.code === 0) {
-          this.notifySvc.success(this.i18nSvc.fanyi('monitors.edit.success'), '');
+          this.notifySvc.success(this.i18nSvc.fanyi('monitor.edit.success'), '');
           this.router.navigateByUrl(`/monitors?app=${info.monitor.app}`);
         } else {
-          this.notifySvc.error(this.i18nSvc.fanyi('monitors.edit.failed'), message.msg);
+          this.notifySvc.error(this.i18nSvc.fanyi('monitor.edit.failed'), message.msg);
         }
       },
       error => {
         this.isSpinning = false;
-        this.notifySvc.error(this.i18nSvc.fanyi('monitors.edit.failed'), error.msg);
+        this.notifySvc.error(this.i18nSvc.fanyi('monitor.edit.failed'), error.msg);
       }
     );
   }
 
   onDetect(info: any) {
     let detectMonitor = {
-      detected: this.detected,
       monitor: info.monitor,
       collector: info.collector,
       params: info.params.concat(info.advancedParams)
     };
-    this.spinningTip = this.i18nSvc.fanyi('monitors.spinning-tip.detecting');
+    this.spinningTip = this.i18nSvc.fanyi('monitor.spinning-tip.detecting');
     this.isSpinning = true;
     this.monitorSvc.detectMonitor(detectMonitor).subscribe(
       message => {
         this.isSpinning = false;
         if (message.code === 0) {
-          this.notifySvc.success(this.i18nSvc.fanyi('monitors.detect.success'), '');
+          this.notifySvc.success(this.i18nSvc.fanyi('monitor.detect.success'), '');
         } else {
-          this.notifySvc.error(this.i18nSvc.fanyi('monitors.detect.failed'), message.msg);
+          this.notifySvc.error(this.i18nSvc.fanyi('monitor.detect.failed'), message.msg);
         }
       },
       error => {
         this.isSpinning = false;
-        this.notifySvc.error(this.i18nSvc.fanyi('monitors.detect.failed'), error.msg);
+        this.notifySvc.error(this.i18nSvc.fanyi('monitor.detect.failed'), error.msg);
       }
     );
   }
 
   onCancel() {
-    let app = this.monitor.app;
-    app = app ? app : '';
-    this.router.navigateByUrl(`/monitors?app=${app}`);
+    this.router.navigateByUrl(`/monitors`);
   }
 }
