@@ -28,6 +28,7 @@ import { finalize } from 'rxjs/operators';
 
 import { AppDefineService } from '../../../service/app-define.service';
 import { GeneralConfigService } from '../../../service/general-config.service';
+import { ThemeService } from '../../../service/theme.service';
 
 @Component({
   selector: 'app-define',
@@ -44,6 +45,7 @@ export class DefineComponent implements OnInit {
     private startUpSvc: StartupService,
     private route: ActivatedRoute,
     private router: Router,
+    private themeSvc: ThemeService,
     @Inject(ALAIN_I18N_TOKEN) private i18nSvc: I18NService
   ) {}
 
@@ -54,7 +56,8 @@ export class DefineComponent implements OnInit {
   loading = false;
   code: string = '';
   originalCode: string = '';
-  dark: boolean = true;
+  dark: boolean = false;
+  theme: string = 'default';
   currentApp: any = null;
   saveLoading = false;
   deleteLoading = false;
@@ -66,6 +69,7 @@ export class DefineComponent implements OnInit {
         this.loadAppDefineContent(this.currentApp);
       }
     });
+    this.theme = this.themeSvc.getTheme() || 'default';
     this.loadMenus();
     this.code = `${this.i18nSvc.fanyi('define.new.code')}\n\n\n\n\n`;
     this.originalCode = this.i18nSvc.fanyi('define.new.code');
