@@ -11,13 +11,11 @@ import { NzRadioComponent, NzRadioGroupComponent } from 'ng-zorro-antd/radio';
 import { NzSwitchComponent } from 'ng-zorro-antd/switch';
 import { NzTagModule } from 'ng-zorro-antd/tag';
 
+import { ConfigurableFieldComponent } from './components/configurable-field/configurable-field.component';
 import { FormFieldComponent } from './components/form-field/form-field.component';
 import { HelpMessageShowComponent } from './components/help-message-show/help-message-show.component';
-import { KeyValueInputComponent } from './components/key-value-input/key-value-input.component';
-import { MetricsFieldInputComponent } from './components/metrics-field-input/metrics-field-input.component';
 import { MonitorSelectMenuComponent } from './components/monitor-select-menu/monitor-select-menu.component';
 import { MultiFuncInputComponent } from './components/multi-func-input/multi-func-input.component';
-import { TagsSelectComponent } from './components/tags-select/tags-select.component';
 import { ToolbarComponent } from './components/toolbar/toolbar.component';
 import { ElapsedTimePipe } from './pipe/elapsed-time.pipe';
 import { I18nElsePipe } from './pipe/i18n-else.pipe';
@@ -27,12 +25,10 @@ import { SHARED_ZORRO_MODULES } from './shared-zorro.module';
 
 const ThirdModules: Array<Type<void>> = [];
 const COMPONENTS: Array<Type<void>> = [
-  KeyValueInputComponent,
   MultiFuncInputComponent,
-  TagsSelectComponent,
   HelpMessageShowComponent,
-  MetricsFieldInputComponent,
   ToolbarComponent,
+  ConfigurableFieldComponent,
   FormFieldComponent,
   MonitorSelectMenuComponent
 ];
